@@ -9,16 +9,13 @@ pub trait Ptr {
     fn ptr(&self) -> &VoidPtr;
 }
 
-pub trait Id: ParameterValues {
+pub trait Id: Code {
     fn id() -> Result<String>;
 }
 
-pub trait Code: ParameterValues {
+pub trait Code {
     fn c_code() -> Result<String>;
-}
-
-pub trait ParameterValues {
-    fn parameter_values() -> Result<Vec<String>>;
+    fn parameters_c_code() -> Result<Vec<String>>;
 }
 
 pub trait IterGet {
@@ -84,3 +81,19 @@ impl<T: IterGet> Iterator for VectorIntoIterator<T> {
         result
     }
 }
+
+#[repr(C)]
+pub struct Pair<X, Y> {
+    x: X,
+    y: Y,
+}
+
+impl<X, Y> From<Pair<X, Y>> for (X, Y) {
+    fn from(pair: Pair<X, Y>) -> (X, Y) {
+        (pair.x, pair.y)
+    }
+}
+
+pub fn array_from_c_array<'a, T>(c_array_ptr: *const T, length: usize) -> &'a [T] {
+    unsafe { std::slice::from_raw_parts(c_array_ptr, length) }
+}
