@@ -2,7 +2,7 @@ use crate::backend::sdsl_c;
 use crate::meta;
 use anyhow::{format_err, Result};
 
-use crate::interface::common::{self, Id, ParameterValues, Ptr};
+use crate::interface::common::{self, Code, Id, Ptr};
 
 /// A rank structure proposed by Sebastiano Vigna.
 ///
@@ -21,7 +21,7 @@ use crate::interface::common::{self, Id, ParameterValues, Ptr};
 /// # Example
 /// ```ignore
 /// let bv = sdsl::bit_vector! {0, 1, 0, 1, 0, 0, 0};
-/// let rs = sdsl::RankSupportV::<sdsl::BitPatterns::P01>::new(&bv)?;
+/// let rs = sdsl::rank_supports::RankSupportV::<sdsl::BitPatterns::P01>::new(&bv)?;
 /// let result = rs.rank(4);
 /// let expected = 2;
 /// assert_eq!(result, expected);
@@ -120,8 +120,8 @@ impl<'a, BitPattern: common::bit_patterns::BitPattern> common::Id for RankSuppor
     fn id() -> Result<String> {
         let meta =
             Box::new(meta::rank_support_v::RankSupportVMeta::new()) as Box<dyn meta::common::Meta>;
-        let parameter_values = Self::parameter_values()?;
-        let id = sdsl_c::specification::get_id(&meta.c_code(&parameter_values)?)?;
+        let parameters_c_code = Self::parameters_c_code()?;
+        let id = sdsl_c::specification::get_id(&meta.c_code(&parameters_c_code)?)?;
         Ok(id)
     }
 }
@@ -132,15 +132,11 @@ impl<'a, BitPattern: common::bit_patterns::BitPattern> common::Code
     fn c_code() -> Result<String> {
         let meta =
             Box::new(meta::rank_support_v::RankSupportVMeta::new()) as Box<dyn meta::common::Meta>;
-        let parameter_values = Self::parameter_values()?;
-        Ok(meta.c_code(&parameter_values)?)
+        let parameters_c_code = Self::parameters_c_code()?;
+        Ok(meta.c_code(&parameters_c_code)?)
     }
-}
 
-impl<'a, BitPattern: common::bit_patterns::BitPattern> common::ParameterValues
-    for RankSupportV<'a, BitPattern>
-{
-    fn parameter_values() -> Result<Vec<String>> {
+    fn parameters_c_code() -> Result<Vec<String>> {
         Ok(vec![BitPattern::c_code()?])
     }
 }
